@@ -132,11 +132,15 @@ def dynamic_admin_factory(admin_cls):
             url = "%schoices/" % request.META.get('HTTP_REFERER')
             app_name, model_name = self.model._meta.app_label, self.model._meta.module_name
             
-            form = modelform_factory(self.model, form=self.form)()
+            # Use get_form in order to allow formfield override
+            # We should create a fake request from referer but all this
+            # hack will be fixed when the code is embed directly in the page
+            form = self.get_form(request)()
             rels = form.get_dynamic_relationships()
             for rel in rels:
+                field_name = rel.split(LOOKUP_SEP)[0]
                 if rel in form.fields:
-                    add_fields(fields, id(rel), [id(field) for field in rels[rel] if field in form.fields])
+                    add_fields(fields, id(field_name), [id(field) for field in rels[rel] if field in form.fields])
                     
             inlines = {}
             for formset in self.get_formsets(request):
@@ -146,7 +150,7 @@ def dynamic_admin_factory(admin_cls):
                 prefix = formset.get_default_prefix()
                 for rel in inline_rels:
                     if LOOKUP_SEP in rel:
-                        base, field, = rel.split(LOOKUP_SEP)
+                        base, field = rel.split(LOOKUP_SEP)[0:2]
                         if base == model_name and field in form.fields:
                             add_fields(fields, id(field), [inline_field_selector(prefix, field) \
                                                            for field in inline_rels[rel] if field in formset_form.fields])
